@@ -261,8 +261,6 @@ static void jammo_editing_track_init(JammoEditingTrack* editing_track) {
 	gst_bin_add_many(GST_BIN(editing_track->priv->bin), editing_track->priv->composition, convert, NULL);
 	g_signal_connect(editing_track->priv->composition, "pad-added", G_CALLBACK(link_compatible_pads), convert);
 
-	/* TODO: There must be at least one glnsource with priority != -1 in order to get pad. */
-
 	pad = gst_element_get_pad(convert, "src");
 	gst_element_add_pad(editing_track->priv->bin, gst_ghost_pad_new("src", pad));
 	gst_object_unref(pad);
@@ -281,6 +279,21 @@ static void jammo_editing_track_init(JammoEditingTrack* editing_track) {
 		     NULL);
 	gst_bin_add(GST_BIN(source), element);
 	gst_bin_add(GST_BIN(editing_track->priv->composition), source);
+
+	source = gst_element_factory_make("gnlsource", NULL);
+	g_object_set(source,
+	             "priority", 1,
+		     "start", 0 * GST_SECOND,
+		     "duration", 1 * GST_SECOND,
+		     "media-start", 0 * GST_SECOND,
+		     "media-duration", 1 * GST_SECOND,
+		     NULL);	
+	element = gst_element_factory_make("audiotestsrc", NULL);
+	g_object_set(element,
+	             "wave", 4, /* GST_AUDIO_TEST_SRC_WAVE_SILENCE */
+		     NULL);
+	gst_bin_add(GST_BIN(source), element);
+	gst_bin_add(GST_BIN(editing_track->priv->composition), source);
 }
 
 static void link_compatible_pads(GstElement* source_element, GstPad* source_pad, GstElement* sink_element) {
