@@ -23,19 +23,28 @@
 #define JAMMO_TRACK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), JAMMO_TYPE_TRACK, JammoTrackClass))
 
 typedef struct _JammoTrackPrivate JammoTrackPrivate;
+typedef struct _JammoTrack JammoTrack;
+typedef struct _JammoTrackClass JammoTrackClass;
 
-typedef struct _JammoTrack {
+struct _JammoTrack {
 	GInitiallyUnowned parent_instance;
-} JammoTrack;
+};
 
-typedef struct _JammoTrackClass {
+/**
+ * JammoTrackClass:
+ * @get_duration: virtual function for getting the total duration of the track
+ * @get_element: virtual function for getting the #GstElement of the track
+ * @receive_message: virtual function for receiving a #GstMessage from the backend
+ * @set_muted: virtual function for setting muting on and off
+ */
+struct _JammoTrackClass {
 	GInitiallyUnownedClass parent_class;
 	
 	guint64 (*get_duration)(JammoTrack* track);
 	GstElement* (*get_element)(JammoTrack* track);
 	void (*receive_message)(JammoTrack* track, GstMessage* message);
 	void (*set_muted)(JammoTrack* track, gboolean muted);
-} JammoTrackClass;
+};
 
 GType jammo_track_get_type(void);
 
